@@ -14,7 +14,7 @@ from gi.repository import GLib, Gtk, Pango, GObject
 
 from lollypop.define import App, ArtSize, ViewType, ArtBehaviour
 from lollypop.define import MARGIN, MARGIN_MEDIUM
-from lollypop.utils import on_query_tooltip, set_cursor_type, emit_signal
+from lollypop.utils import on_query_tooltip, emit_signal
 
 
 class AlbumSimpleWidget(Gtk.FlowBoxChild):
@@ -40,13 +40,24 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild):
         self.__genre_ids = genre_ids
         self.__artist_ids = artist_ids
         self.__artwork = None
+        self.__view_type = view_type
         self.__font_height = font_height
-        self.set_view_type(view_type)
         self.set_property("halign", Gtk.Align.CENTER)
         if view_type & ViewType.ALBUM:
             self.set_property("margin", MARGIN_MEDIUM)
         else:
             self.set_property("margin", MARGIN)
+        self.update_art_size()
+
+    def do_get_preferred_width(self):
+        """
+            Return preferred width
+            @return (int, int)
+        """
+        if self.__artwork is None:
+            return (0, 0)
+        width = Gtk.FlowBoxChild.do_get_preferred_width(self)[0]
+        return (width, width)
 
     def populate(self):
         """
@@ -68,6 +79,14 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild):
             album_name = GLib.markup_escape_text(self.__album.name)
             if self.__view_type & ViewType.ALBUM:
                 self.__label.set_markup(album_name)
+            elif self.__view_type & ViewType.ARTIST:
+                if self.__album.year and\
+                        App().settings.get_value("show-year-below-name"):
+                    self.__label.set_markup(
+                        "<b>%s</b>\n<span alpha='25000'>%s</span>" % (
+                            album_name, self.__album.year))
+                else:
+                    self.__label.set_markup("<b>%s</b>" % album_name)
             else:
                 artist_name = GLib.markup_escape_text(", ".join(
                                                       self.__album.artists))
@@ -75,7 +94,6 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild):
                     "<b>%s</b>\n<span alpha='50000'>%s</span>" % (album_name,
                                                                   artist_name))
             self.__artwork = Gtk.Image.new()
-            self.__artwork.connect("realize", set_cursor_type)
             grid.add(self.__artwork)
             grid.add(self.__label)
             self.set_artwork()
@@ -85,12 +103,25 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild):
         else:
             self.set_artwork()
 
-    def disable_artwork(self):
+    def update_art_size(self):
         """
-            Disable widget artwork
+            Update art size based on current window state
         """
+        if self.__view_type & ViewType.SMALL:
+            self.__art_size = ArtSize.MEDIUM
+        elif App().window.folded:
+            self.__art_size = ArtSize.BANNER
+        else:
+            self.__art_size = ArtSize.BIG
+        self.set_size_request(self.__art_size,
+                              self.__art_size + self.__font_height * 2)
+
+    def reset_artwork(self):
+        """
+            Reset widget artwork
+        """
+        self.update_art_size()
         if self.__artwork is not None:
-            self.__artwork.set_size_request(self.__art_size, self.__art_size)
             self.__artwork.set_from_surface(None)
 
     def set_artwork(self):
@@ -115,31 +146,6 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild):
                                            ArtBehaviour.CROP_SQUARE,
                                            self.__on_album_artwork)
 
-    def set_view_type(self, view_type):
-        """
-            Update artwork size
-            @param view_type as ViewType
-        """
-        self.__view_type = view_type
-        if self.__view_type & ViewType.SMALL:
-            self.__art_size = ArtSize.MEDIUM
-        elif self.__view_type & ViewType.ADAPTIVE:
-            self.__art_size = ArtSize.BANNER
-        else:
-            self.__art_size = ArtSize.BIG
-        self.set_size_request(self.__art_size,
-                              self.__art_size + self.__font_height * 2)
-
-    def do_get_preferred_width(self):
-        """
-            Return preferred width
-            @return (int, int)
-        """
-        if self.__artwork is None:
-            return (0, 0)
-        width = Gtk.FlowBoxChild.do_get_preferred_width(self)[0]
-        return (width, width)
-
     def set_selection(self):
         """
             Mark widget as selected if currently playing
@@ -165,7 +171,10 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild):
             Get name
             @return str
         """
-        return "%s %s" % (self.__album.name, self.__album.artists)
+        if self.__view_type & (ViewType.ALBUM | ViewType.ARTIST):
+            return self.__album.name
+        else:
+            return "%s %s" % (self.__album.name, self.__album.artists)
 
     @property
     def artwork(self):
